@@ -100,13 +100,21 @@ def run_bindetect(args):
 	pool = mp.Pool(processes=worker_cores)
 	writer_pool = mp.Pool(processes=writer_cores)
 
-
 	#-------------------------------------------------------------------------------------------------------------#
 	#-------------------------- Pre-processing data: Reading motifs, sequences, peaks ----------------------------#
 	#-------------------------------------------------------------------------------------------------------------#
 
 	logger.info("----- Processing input data -----")
 
+	#Check that cond_names are the right length and are unique:
+	if len(args.cond_names) != len(args.signals):
+		logger.error("The given number of given '--cond-names' ({0}) differ from the given input '--signals' ({1}). Please enter one condition name per signal.".format(len(args.cond_names), len(args.signals)))
+		sys.exit(1)
+
+	if len(args.cond_names) != len(set(args.cond_names)):
+		logger.error("The condition names are not unique ({0}). Please use --cond-names to set a unique set of condition names.".format(args.cond_names))
+		sys.exit(1)
+
 	#Check opening/writing of files
 	logger.info("Checking reading/writing of files")
 	check_files([args.signals, args.motifs, args.genome, args.peaks], action="r")
@@ -138,7 +146,8 @@ def run_bindetect(args):
 	#output and order
 	titles = []
 	titles.append("Raw score distributions")
-	titles.append("Normalized score distributions")
+	if no_conditions > 1 and args.norm_off == False:
+		titles.append("Normalized score distributions")
 	if args.debug:
 		for (cond1, cond2) in comparisons:
 			titles.append("Background log2FCs ({0} / {1})".format(cond1, cond2))	
@@ -161,7 +170,7 @@ def run_bindetect(args):
 	for i, peak in enumerate(peaks):
 		if len(peak) != n_cols:
 			logger.error("The lines in --peaks have a varying number of columns. Line 1 has {0} columns, but line {1} has {2} columns! Please adjust the format of this file to run TOBIAS BINDetect.".format(n_cols, i+1, len(peak)))
-			sys.exit()
+			sys.exit(1)
 
 	#Merge overlapping peaks
 	peaks = peaks.merge()	
@@ -169,7 +178,7 @@ def run_bindetect(args):
 
 	if len(peaks) == 0:
 		logger.error("Input --peaks file is empty!")
-		sys.exit()
+		sys.exit(1)
 		
 	#Read header and check match with number of peak columns
 	peak_columns = len(peaks[0]) #number of columns
@@ -182,7 +191,7 @@ def run_bindetect(args):
 		#Check whether peak header fits with number of peak columns
 		if len(args.peak_header_list) != peak_columns:
 			logger.error("Length of --peak_header ({0}) does not fit number of columns in --peaks ({1}).".format(len(args.peak_header_list), peak_columns))
-			sys.exit()
+			sys.exit(1)
 	else:
 		args.peak_header_list = ["peak_chr", "peak_start", "peak_end"] + ["additional_" + str(num + 1) for num in range(peak_columns-3)]
 	logger.debug("Peak header list: {0}".format(args.peak_header_list))
@@ -235,8 +244,8 @@ def run_bindetect(args):
 		logger.spam("Getting pssm for motif {0}".format(motif.name))
 		motif.get_pssm()
 	
-	#Check that prefixes are unique
-	motif_prefixes = [motif.prefix for motif in motif_list]
+	#Check that prefixes are unique regardless of upper/lower case name
+	motif_prefixes = [motif.prefix.upper() for motif in motif_list]
 	name_count = Counter(motif_prefixes)
 	if max(name_count.values()) > 1:
 
@@ -247,12 +256,12 @@ def run_bindetect(args):
 		
 		motif_count = {dup_motif: 1 for dup_motif in duplicated}
 		for i, motif in enumerate(motif_list):
-			if motif.prefix in duplicated:
+			if motif.prefix.upper() in duplicated:
 				
 				original_name = motif.prefix
-				motif.prefix = motif.prefix + "_{0}".format(motif_count[motif.prefix])	#Add number to make prefix unique
+				motif.prefix = motif.prefix + "_{0}".format(motif_count[motif.prefix.upper()])	#Add number to make prefix unique
 				logger.debug("Renamed motif {0}: {1} -> {2}".format(i+1, original_name, motif.prefix))
-				motif_count[original_name] += 1
+				motif_count[original_name.upper()] += 1
 
 	motif_names = [motif.prefix for motif in motif_list]
 
@@ -392,7 +401,7 @@ def run_bindetect(args):
 	#Collect sampled background values
 	for bigwig in args.cond_names:
 		background["signal"][bigwig] = np.array(background["signal"][bigwig])
-	
+
 	#Check how many values were fetched from background
 	n_bg_values = len(background["signal"][args.cond_names[0]])
 	logger.debug("Collected {0} values from background".format(n_bg_values))
@@ -402,41 +411,46 @@ def run_bindetect(args):
 		err_str += "To improve this estimation, please run BINDetect with --peaks = the full peak set across all conditions."
 		logger.warning(err_str) 
 
-	#Normalize scores between conditions
-	logger.comment("")
-	logger.info("Estimating score distribution per condition")
+	#Plot score distribution
 	fig = plot_score_distribution([background["signal"][bigwig] for bigwig in args.cond_names], labels=args.cond_names, title="Raw scores per condition")
 	figure_pdf.savefig(fig, bbox_inches='tight')
 	plt.close()
 
-	logger.info("Normalizing scores across conditions")
-	list_of_vals = [background["signal"][bigwig] for bigwig in args.cond_names]
+	#Normalize arrays
 	args.norm_objects = {}
+	if args.norm_off == True or len(args.cond_names) == 1: #if norm_off or length of cond is 1 - create constant normalization
+		for bigwig in args.cond_names:
+			args.norm_objects[bigwig] = ArrayNorm("constant", popt=1.0, value_min=0, value_max=1) #no normalization; min/max don't matter for constant norm
 
-	if args.debug: 
-		args.norm_objects = quantile_normalization(list_of_vals, args.cond_names, pdfpages=debug_pdf, logger=logger)
 	else:
-		args.norm_objects = quantile_normalization(list_of_vals, args.cond_names, logger=logger)
+		logger.comment("")
+		logger.info("Normalizing scores across conditions")
 
-	#Normalize background and visualize score distribution
-	for bigwig in args.cond_names:
+		list_of_vals = [background["signal"][bigwig] for bigwig in args.cond_names]
+		if args.debug: 
+			args.norm_objects = quantile_normalization(list_of_vals, args.cond_names, pdfpages=debug_pdf, logger=logger)
+		else:
+			args.norm_objects = quantile_normalization(list_of_vals, args.cond_names, logger=logger)
+
+		#Normalize background and visualize score distribution
+		for bigwig in args.cond_names:
+			
+			original = background["signal"][bigwig]
+
+			#Check for nan
+			logger.debug("Background nans ({0}): {1}".format(bigwig, sum(np.isnan(original))))
+			normalized = args.norm_objects[bigwig].normalize(original)
+			
+			#Replace negative values with 0
+			negatives = normalized < 0
+			normalized[negatives] = 0
+
+			background["signal"][bigwig] = normalized
+			logger.debug("Background nans after normalization ({0}): {1}".format(bigwig, sum(np.isnan(background["signal"][bigwig]))))
 		
-		original = background["signal"][bigwig]
-
-		#Check for nan
-		logger.debug("Background nans ({0}): {1}".format(bigwig, sum(np.isnan(original))))
-		normalized = args.norm_objects[bigwig].normalize(original)
-		
-		#Replace negative values with 0
-		negatives = normalized < 0
-		normalized[negatives] = 0
-
-		background["signal"][bigwig] = normalized
-		logger.debug("Background nans after normalization ({0}): {1}".format(bigwig, sum(np.isnan(background["signal"][bigwig]))))
-	
-	fig = plot_score_distribution([background["signal"][bigwig] for bigwig in args.cond_names], labels=args.cond_names, title="Normalized scores per condition")
-	figure_pdf.savefig(fig, bbox_inches='tight')
-	plt.close()
+		fig = plot_score_distribution([background["signal"][bigwig] for bigwig in args.cond_names], labels=args.cond_names, title="Normalized scores per condition")
+		figure_pdf.savefig(fig, bbox_inches='tight')
+		plt.close()
 
 
 	#-------------------------------------------------------------------------------------------------------------#
@@ -452,31 +466,66 @@ def run_bindetect(args):
 	logger.debug("Size of background array after filtering > 0: {0}".format(bg_values.size))
 	if len(bg_values) == 0:
 		logger.error("Error processing bigwig scores from background. It could be that there are no scores in the bigwig (= all scores are 0) assigned for the peaks. Please check your input files.")
-		sys.exit()
+		sys.exit(1)
 
 	x_max = np.percentile(bg_values, [99]) 
 	bg_values = bg_values[bg_values < x_max]
 	logger.debug("Size of background array after filtering < x_max ({0}): {1}".format(x_max, bg_values.size))
 
 	#Fit mixture of normals
+	log_vals = np.log(bg_values).reshape(-1, 1)
 	lowest_bic = np.inf
-	for n_components in [2]:	#2 components
+	for n_components in [2]:	#2 components; one for 0's and one for true signal
 		gmm = sklearn.mixture.GaussianMixture(n_components=n_components, random_state=1)
-		gmm.fit(np.log(bg_values).reshape(-1, 1))
+		gmm.fit(log_vals)
 		
-		bic = gmm.bic(np.log(bg_values).reshape(-1,1))
+		bic = gmm.bic(log_vals)
 		logger.debug("n_compontents: {0} | bic: {1}".format(n_components, bic))
 		if bic < lowest_bic:
 			lowest_bic = bic
 			best_gmm = gmm
 	gmm = best_gmm
 	
-	#Extract most-right gaussian 
+	#Obtain parameters for each component
 	means = gmm.means_.flatten()
-	sds = np.sqrt(gmm.covariances_).flatten()	
-	chosen_i = np.argmax(means) 	#Mixture with largest mean
+	stds = np.sqrt(gmm.covariances_).flatten()	
 
-	log_params = scipy.stats.lognorm.fit(bg_values[bg_values < x_max], f0=sds[chosen_i], fscale=np.exp(means[chosen_i]))
+	#Plot components for debugging
+	if args.debug:
+
+		fig, ax = plt.subplots(nrows=2, ncols=1, constrained_layout=True)
+
+		#Plot background distribution
+		ax[0].hist(log_vals, bins='auto', density=True, color="grey")  #log space
+		ax[1].hist(bg_values, bins='auto', density=True, color="grey") #normal space
+
+		#Plot components
+		x_log = np.linspace(np.min(log_vals), np.max(log_vals), 1000) 
+		x_norm = np.exp(x_log)
+		for i in range(len(means)):
+			pdf = scipy.stats.norm.pdf(x_log, loc=means[i], scale=stds[i])
+			ax[0].plot(x_log, pdf, label="Component {0}".format(i+1))
+
+			#Plot component in normal space
+			log_params = scipy.stats.lognorm.fit(bg_values, f0=stds[i], fscale=np.exp(means[i]))
+			pdf =  scipy.stats.lognorm.pdf(x_norm, *log_params)
+			ax[1].plot(x_norm, pdf, label="Component {0}".format(i+1))
+
+		ax[0].set_title("Background score distribution")
+		ax[0].set_xlabel("log(background score)")
+		ax[0].set_ylabel("Density")
+		ax[0].legend()
+
+		ax[1].set_xlabel("Background score")
+		ax[1].set_ylabel("Density")
+		ax[1].legend()
+
+		debug_pdf.savefig(fig)
+		plt.close()
+
+	#Extract most-right gaussian 
+	chosen_i = np.argmax(means) 	#Mixture with largest mean
+	log_params = scipy.stats.lognorm.fit(bg_values, f0=stds[chosen_i], fscale=np.exp(means[chosen_i]))
 
 	#Mode of distribution
 	mode = scipy.optimize.fmin(lambda x: -scipy.stats.lognorm.pdf(x, *log_params), 0, disp=False)[0]
@@ -490,7 +539,8 @@ def run_bindetect(args):
 	leftside_pdf = scipy.stats.lognorm.pdf(leftside_x, *log_params)
 
 	#Flip over
-	mirrored_x = np.concatenate([leftside_x, np.max(leftside_x) + leftside_x]).flatten()
+	leftside_x_scale = leftside_x - np.min(leftside_x) #scale to min 0
+	mirrored_x = np.concatenate([leftside_x, np.max(leftside_x) + leftside_x_scale]).flatten()
 	mirrored_pdf = np.concatenate([leftside_pdf, leftside_pdf[::-1]]).flatten()
 	popt, cov = scipy.optimize.curve_fit(lambda x, std, sc: sc * scipy.stats.norm.pdf(x, mode, std), mirrored_x, mirrored_pdf)
 	norm_params = (mode, popt[0])
@@ -505,7 +555,16 @@ def run_bindetect(args):
 	#Only plot if args.debug is True
 	if args.debug:
 
-		#Plot fit
+		#Plot mirrored data
+		fig, ax = plt.subplots(1,1)
+		ax.hist(bg_values[bg_values < x_max], bins='auto', density=True, label="Observed score distribution")
+		ax.plot(mirrored_x, mirrored_pdf, color="black")
+		plt.xlabel("Bigwig score")
+		plt.title("Theoretical normal")
+		debug_pdf.savefig(fig)
+		plt.close(fig)
+		
+		#Plot fit and threshold
 		fig, ax = plt.subplots(1, 1)
 		ax.hist(bg_values[bg_values < x_max], bins='auto', density=True, label="Observed score distribution")
 
@@ -700,6 +759,20 @@ def run_bindetect(args):
 		info_table[base + "_change"] = info_table[base + "_change"].round(5)
 		info_table[base + "_pvalue"] = info_table[base + "_pvalue"].map("{:.5E}".format, na_action="ignore")
 
+		#Define whether TF is going to be highlighted in plot
+		names = info_table["output_prefix"]
+		changes = info_table[base + "_change"].astype(float)
+		pvalues = info_table[base + "_pvalue"].astype(float)
+		pval_min = np.percentile(pvalues[pvalues > 0], 5)	#5% smallest pvalues
+		change_min, change_max = np.percentile(changes, [5, 95])	#5% smallest and largest changes
+		
+		#Add "highlighted" information to info_table
+		for i, (change, pvalue) in enumerate(zip(changes, pvalues)):
+			if change < change_min or change > change_max or pvalue < pval_min:
+				info_table.at[names[i], base + "_highlighted"] = True
+			else:
+				info_table.at[names[i], base + "_highlighted"] = False
+	
 	#Write bindetect results tables
 	#info_table.insert(0, "TF_name", info_table.index)	 #Set index as first column
 	bindetect_out = os.path.join(args.outdir, args.prefix + "_results.txt")
@@ -725,21 +798,16 @@ def run_bindetect(args):
 			logger.info("- {0} / {1} (static plot)".format(cond1, cond2))
 			base = cond1 + "_" + cond2
 
-			#Define which motifs to show
-			xvalues = info_table[base + "_change"].astype(float)
-			yvalues = info_table[base + "_pvalue"].astype(float)
-			y_min = np.percentile(yvalues[yvalues > 0], 5)	#5% smallest pvalues
-			x_min, x_max = np.percentile(xvalues, [5, 95])	#5% smallest and largest changes
-
 			#Fill motifs with metadata (.change, .pvalue, .logpvalue etc.)
 			for motif in motif_list:
 				name = motif.prefix
 				motif.change = float(info_table.at[name, base + "_change"])	#change for this comparison
 				motif.pvalue = float(info_table.at[name, base + "_pvalue"])	#pvalue for this comparison
 				motif.logpvalue = -np.log10(motif.pvalue) if motif.pvalue > 0 else -np.log10(1e-308)
+				motif.highlighted = info_table.at[name, base + "_highlighted"]
 
 				#Assign each motif to group
-				if motif.change < x_min or motif.change > x_max or motif.pvalue < y_min:
+				if motif.highlighted == True:
 					if motif.change < 0:
 						motif.group = cond2 + "_up"
 					if motif.change > 0:
